
#include <stdio.h>
#include <stdlib.h>
#include "error.h"


#include "mfhdf.h"


#ifdef ECS
#include "PGS_SMF.h"
#endif



int report_error(int code, int line, char *file)
{
	char msg[256];

	/* skip file/location information if zero line number or null string */
	if (file && (line > 0)) {
		(void) sprintf(msg, "*** FATAL ERROR (file \"%s\", line %d):",
			file, line);
		errmsg(msg);
		}


	switch (code) {
		case ERR_HDF:
			errmsg("HDF library error.");
			HEprint(stderr, 0);
			break;

		case ERR_HDF_QUIET:
			/* like ERR_HDF except don't print HDF error message */
			break;

		case ERR_F_MEM:
			errmsg("Unable to allocate memory.");
			break;

		case ERR_DATA_TYPE:
			errmsg("Unexpected data type within HDF file.");
			break;

		case ERR_DATA_RANK:
			errmsg("Unexpected data rank within HDF file.");
			break;

		case ERR_DATA_SIZE:
			errmsg("Unexpected data size within HDF file.");
			break;

		case ERR_IMAGE_LINES:
			errmsg("Number of lines in granule not a multiple of 10.");
			break;

		case ERR_NLINES_MISMATCH:
			errmsg("Number of scans in MOD021KM and MOD03 files do not match.");
			break;
#ifdef ECS
		case ERR_PGS_MET:
			errmsg("SDP Toolkit PGS_MET function error.");
			break;

		case ERR_PGS_PC:
			errmsg("SDP Toolkit PGS_PC function error.");
			break;

		case ERR_F_MISSING_PCF_FIELD:
			errmsg("Error reading parameter from PCF.");
			break;

		case ERR_CORE_META_READ:
			errmsg("Error reading core metadata from input file.");
			break;

		case ERR_CORE_META_WRITE:
			errmsg("Error writing core metadata to output file.");
			break;

		case ERR_ARCH_META_WRITE:
			errmsg("Error writing archive metadata to output file.");
			break;

		case ERR_SAT_HYBRID:
			errmsg("MOD14 cannot perform mixed Terra/Aqua processing.");
			break;
#endif
		}

	return code;
}



void report_warn(char *msg, int line, char *file)
{
	char s[256];

	/* skip file/location information if zero line number or null string */
	if (file && (line > 0)) {
		(void) sprintf(s, "*** WARNING (file \"%s\", line %d):",
			file, line);
		errmsg(s);
		}

	errmsg(msg);
}



/* adds newline to error message so caller doesn't need to provide it */
void errmsg(char *msg)
{
#ifdef ECS
	/* write to status file */
	(void) PGS_SMF_GenerateStatusReport(msg);
	(void) PGS_SMF_SetDynamicMsg(PGSSMF_E_UNDEFINED_CODE, msg, (char *) NULL);
#else
	(void) fputs(msg, stderr);
	(void) fputc('\n', stderr);
#endif
}


