#include <math.h>

#ifdef OLD_RED_HAT
#include "old_red_hat.h"
#endif

#ifdef NO_SINGLE_MATH
#include "no_sing_math.h"
#endif 


static float pow5(float x);



float InversePlanck(float L, float lambda)
/*
!C*****************************************************************************
!Description:
	Invert Planck Function to compute blackbody temperature.
!Input Parameters:
	L		radiance (W/m^2/str/micron)
	lambda		wavelength (microns)

!Output Parameters:
	Returns blackbody temperature (Kelvin).

!Revision History:
	Original version August 1996, L. Giglio (giglio@hades.gsfc.nasa.gov).

!Team-unique Header:
        References and Credits
        Design Notes
!END***************************************************************************
*/
{
	float num, denom;
	const float C1 = 1.19107e8F;	/* W micron^4 / m^2 sr */
	const float C2 = 1.43883e4F;	/* micron K */

	num = C2 / lambda;
	denom = logf(1.0F + C1/(L * pow5(lambda)));

	return num / denom;
}




static float pow5(float x)
/*
!C*****************************************************************************
!Description:
	Raise float value to 5'th power (quickly).  Equivalent to powf(x,5.0F),
	but faster and slightly less precise.  (We do not need the higher precision,
	however.)

!Input Parameters:
	x	argument (float)

!Output Parameters:
	Returns x to the fifth power.

!Revision History:
	Original version August 1996, L. Giglio (giglio@hades.gsfc.nasa.gov).

!Team-unique Header:
        References and Credits
        Design Notes
!END***************************************************************************
*/
{
	float x2;

	x2 = x * x;

	return x * x2 * x2;
}

