
typedef unsigned char UBYTE;
typedef unsigned short USHORT;


/* pixel-level flags and values used internally by algorithm */
typedef struct {
	unsigned day		: 1;	/* daytime = 1, nighttime = 0 */
	unsigned valid_bkg_pix	: 1;	/* flag: valid background pixel */
	unsigned potential_fire	: 1;	/* flag: potential fire pixel */
	unsigned high_range	: 1;	/* flag: using band 21 in place of 22 */
	unsigned cloud		: 1;	/* flag: cloud pixel */
	unsigned water		: 1;	/* flag: water pixel */
	unsigned clear_land	: 1;	/* flag: clear land pixel having valid data */
	unsigned bkg_fire	: 1;	/* flag: probable background-fire pixel */
	unsigned glint_level	: 2;	/* sun glint level (0-3) */
	} PixInfo;


typedef struct {
	float	L21[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	float	L22[LINES_PER_SCAN_1KM][SAMPLES_1KM];

	float	T21[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	float	T22[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	float	T31[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	float	T32[LINES_PER_SCAN_1KM][SAMPLES_1KM];

	float	R1[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	float	R2[LINES_PER_SCAN_1KM][SAMPLES_1KM];

	float	R7[LINES_PER_SCAN_1KM][SAMPLES_1KM];

	float32	lat[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	float32	lon[LINES_PER_SCAN_1KM][SAMPLES_1KM];

	float	SolZenAng[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	float	SolAzAng[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	float	ViewZenAng[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	float	ViewAzAng[LINES_PER_SCAN_1KM][SAMPLES_1KM];

	uint8	landsea[LINES_PER_SCAN_1KM][SAMPLES_1KM];

	/* used internally by algorithm */
	PixInfo	pixflags[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	} Scan;


typedef struct{
	int32 NumPix;
  
	int32 NumMissingPix;
	int32 NumLandPix;
	int32 NumFirePix;
  
	int32 NumWaterPix;
	int32 NumUnknownPix;
	int32 NumNoFirePix;
	int32 NumGlintPix;
	int32 NumGlintRejectPix;
	int32 NumCoastRejectPix;
	int32 NumHotRejectPix;

	int32 NumWaterAdjFirePix;
	int32 NumCloudAdjFirePix;

	int32 NumWaterCloudPix;
	int32 NumLandCloudPix;

	int32 NumDayPix;
	int32 NumNightPix;

	int32 NumGoodQuality;
	int32 NumOtherQuality;
	int32 NumNotProducedCloud;
	int32 NumNotProducedOther;
	} FireCounts;



enum Satellite {SAT_TERRA, SAT_AQUA, SAT_UNKNOWN};


